pub struct OperandSegmentSizesAttr(pub Vec<u32>);Tuple Fields
0: Vec<u32>Trait Implementations
Sourceimpl Attribute for OperandSegmentSizesAttr
impl Attribute for OperandSegmentSizesAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for OperandSegmentSizesAttr
impl Clone for OperandSegmentSizesAttr
Sourcefn clone(&self) -> OperandSegmentSizesAttr
fn clone(&self) -> OperandSegmentSizesAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperandSegmentSizesAttr
impl Debug for OperandSegmentSizesAttr
Sourceimpl Hash for OperandSegmentSizesAttr
impl Hash for OperandSegmentSizesAttr
Sourceimpl Parsable for OperandSegmentSizesAttr
impl Parsable for OperandSegmentSizesAttr
Sourcetype Parsed = OperandSegmentSizesAttr
type Parsed = OperandSegmentSizesAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<StateStream<'a>, Output = Self::Parsed, PartialState = ()> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<StateStream<'a>, Output = Self::Parsed, PartialState = ()> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for OperandSegmentSizesAttr
impl PartialEq for OperandSegmentSizesAttr
Sourceimpl Printable for OperandSegmentSizesAttr
impl Printable for OperandSegmentSizesAttr
impl Eq for OperandSegmentSizesAttr
impl StructuralPartialEq for OperandSegmentSizesAttr